==> mastercard_spendcontrols-1.0.1.tar.gz: mastercard_spendcontrols-1.0.1/mastercardspendcontrols/declines.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Declines(BaseObject):
	"""
	
	"""

	__config = {
		
		"7c94b44a-956f-4625-a623-82027b4c1b7d" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines", "delete", [], []),
		
		"b761d9cd-b608-4c26-b931-c269fa82a0ca" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines", "query", [], []),
		
		"3ee05eca-da32-4c75-a6f1-8adebb6002fd" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Declines by id

		@param str id
		@return Declines of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("7c94b44a-956f-4625-a623-82027b4c1b7d", Declines(mapObj))

	def delete(self):
		"""
		Delete object of type Declines

		@return Declines of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("7c94b44a-956f-4625-a623-82027b4c1b7d", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Declines by id and optional criteria
		@param type criteria
		@return Declines object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("b761d9cd-b608-4c26-b931-c269fa82a0ca", Declines(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Declines

		@param Dict mapObj, containing the required parameters to create a new object
		@return Declines of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("3ee05eca-da32-4c75-a6f1-8adebb6002fd", Declines(mapObj))

==> mastercard_spendcontrols-1.0.2.tar.gz: mastercard_spendcontrols-1.0.2/mastercardspendcontrols/declines.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Declines(BaseObject):
	"""
	
	"""

	__config = {
		
		"be5d4b66-cca4-439e-a47a-2a293c78278c" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines", "delete", [], []),
		
		"fa748ef0-f5f2-4848-b212-85db49c6e212" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines", "query", [], []),
		
		"567be31b-6c4a-41d2-8438-1b16b972b1ad" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Declines by id

		@param str id
		@return Declines of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("be5d4b66-cca4-439e-a47a-2a293c78278c", Declines(mapObj))

	def delete(self):
		"""
		Delete object of type Declines

		@return Declines of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("be5d4b66-cca4-439e-a47a-2a293c78278c", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Declines by id and optional criteria
		@param type criteria
		@return Declines object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("fa748ef0-f5f2-4848-b212-85db49c6e212", Declines(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Declines

		@param Dict mapObj, containing the required parameters to create a new object
		@return Declines of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("567be31b-6c4a-41d2-8438-1b16b972b1ad", Declines(mapObj))
